@@ -1,11 +1,10 @@
+use strict; use warnings;
 package Lingy::Lang::HashMap;
 
-use Lingy::Base 'Map';
-
-use constant lingy_class => 'host.lang.HashMap';
+use base 'Lingy::Lang::Class';
+use Lingy::Common;
 
 use Tie::IxHash;
-use Lingy::Common();
 
 *err = \&Lingy::Common::err;
 
@@ -15,7 +14,7 @@ sub new {
         my $key = $list->[$i];
         if (my $type = ref($key)) {
             err "Type '$type' not supported as a hash-map key"
-                if not($key->isa('Lingy::Base::Scalar')) or $type eq 'Lingy::Lang::Symbol';
+                if not($key->isa('Lingy::Lang::ScalarClass')) or $type eq 'Lingy::Lang::Symbol';
             $list->[$i] = $type eq 'Lingy::Lang::String'
                 ? qq<"$key>
                 : qq<$key>;
